Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(271)

Unified Diff: ui/views/bubble/bubble_frame_view.h

Issue 10905311: Consolidate bubble border code. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/views/bubble/bubble_frame_view.h
diff --git a/ui/views/bubble/bubble_frame_view.h b/ui/views/bubble/bubble_frame_view.h
index 0f014288a1a70f9d2c3e5c785d753ef6518ecaf5..f13ccd04a746f340696cf686d25b538a0027413a 100644
--- a/ui/views/bubble/bubble_frame_view.h
+++ b/ui/views/bubble/bubble_frame_view.h
@@ -42,10 +42,10 @@ class VIEWS_EXPORT BubbleFrameView : public NonClientFrameView {
// Given the size of the contents and the rect to point at, returns the bounds
// of the bubble window. The bubble's arrow location may change if the bubble
// does not fit on the monitor and |try_mirroring_arrow| is true.
gfx::Rect GetUpdatedWindowBounds(const gfx::Rect& anchor_rect,
gfx::Size client_size,
- bool try_mirroring_arrow);
+ bool try_fit_bubble);
void SetBubbleBorder(BubbleBorder* border);
@@ -63,6 +63,11 @@ class VIEWS_EXPORT BubbleFrameView : public NonClientFrameView {
const gfx::Rect& anchor_rect,
const gfx::Size& client_size);
+ // Move arrow (by setting its offset) to make bubble fit in the monitor
+ // bounds.
+ void OffsetArrowIfOffScreen(const gfx::Rect& anchor_rect,
+ const gfx::Size& client_size);
+
// The bubble border.
BubbleBorder* bubble_border_;
@@ -42,10 +42,10 @@ class VIEWS_EXPORT BubbleFrameView : public NonClientFrameView {
// Given the size of the contents and the rect to point at, returns the bounds
// of the bubble window. The bubble's arrow location may change if the bubble
- // does not fit on the monitor and |try_mirroring_arrow| is true.
+ // does not fit on the monitor and |try_fit_bubble| is true.
gfx::Rect GetUpdatedWindowBounds(const gfx::Rect& anchor_rect,
gfx::Size client_size,

Powered by Google App Engine
This is Rietveld 408576698